CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
66 lines
1.6 KiB
C++
66 lines
1.6 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <performance_common.hh>
|
|
|
|
/**
|
|
* @addtogroup stream stream
|
|
* @{
|
|
* @ingroup PerformanceTestStream
|
|
*/
|
|
|
|
class StreamGetFlagsBenchmark : public Benchmark<StreamGetFlagsBenchmark> {
|
|
public:
|
|
void operator()(unsigned int expected_flag) {
|
|
unsigned int returned_flags{};
|
|
hipStream_t stream;
|
|
|
|
HIP_CHECK(hipStreamCreateWithFlags(&stream, expected_flag));
|
|
TIMED_SECTION(kTimerTypeCpu){HIP_CHECK(hipStreamGetFlags(stream, &returned_flags))} HIP_CHECK(
|
|
hipStreamDestroy(stream));
|
|
}
|
|
};
|
|
|
|
static void RunBenchmark(unsigned int expected_flag) {
|
|
StreamGetFlagsBenchmark benchmark;
|
|
switch (expected_flag) {
|
|
case hipStreamDefault:
|
|
benchmark.AddSectionName("hipStreamDefault");
|
|
break;
|
|
case hipStreamNonBlocking:
|
|
benchmark.AddSectionName("hipStreamNonBlocking");
|
|
break;
|
|
default:
|
|
benchmark.AddSectionName("unknown flag type");
|
|
}
|
|
benchmark.Run(expected_flag);
|
|
}
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Executes `hipStreamGetFlags`:
|
|
* -# Flags:
|
|
* - `hipStreamDefault`
|
|
* - `hipStreamNonBlocking`
|
|
* Test source
|
|
* ------------------------
|
|
* - performance/api/stream/hipStreamGetFlags.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
*/
|
|
HIP_TEST_CASE(Performance_hipStreamGetFlags) {
|
|
unsigned int expected_flag = GENERATE(hipStreamDefault, hipStreamNonBlocking);
|
|
RunBenchmark(expected_flag);
|
|
}
|
|
|
|
/**
|
|
* End doxygen group PerformanceTest.
|
|
* @}
|
|
*/
|